@@ -10,12 +10,16 @@ import typing_extensions
 
 import aws_cdk._jsii
 import aws_cdk.aws_cognito_identitypool_alpha._jsii
+import aws_prototyping_sdk.pdk_nag._jsii
 import cdk_nag._jsii
 import constructs._jsii
 import projen._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
-    "@aws-prototyping-sdk/identity", "0.3.8", __name__[0:-6], "identity@0.3.8.jsii.tgz"
+    "@aws-prototyping-sdk/identity",
+    "0.3.10",
+    __name__[0:-6],
+    "identity@0.3.10.jsii.tgz",
 )
 
 __all__ = [
